@@ -11,4 +11,11 @@ class Tiller(Plugin):
 		print('\n\n\tAdded!\n\n')
 	
 	def run(self):
-		print(self.getData('string'))
\ No newline at end of file
+		print(self.getData('string'))
+
+def command():
+	print('Hello, World!')
+	input()
+
+if __name__ == '__main__':
+	command()
\ No newline at end of file
